@@ -14,7 +14,7 @@ along with this library; if not, write to the Free Software Foundation, Inc.,
 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301  USA
 **********/
 // "liveMedia"
-// Copyright (c) 1996-2019 Live Networks, Inc.  All rights reserved.
+// Copyright (c) 1996-2022 Live Networks, Inc.  All rights reserved.
 // A class that encapsulates an Ogg file.
 // Implementation
 
@@ -56,13 +56,38 @@ OggTrack* OggFile::lookup(u_int32_t trackNumber) {
   return fTrackTable->lookup(trackNumber);
 }
 
-OggDemux* OggFile::newDemux() {
+struct DemuxRecord {
+  OggDemux* demux;
+  OggDemuxOnDeletionFunc* onDeletionFunc;
+  void* objectToNotify;
+};
+
+OggDemux* OggFile
+::newDemux(OggDemuxOnDeletionFunc* onDeletionFunc, void* objectToNotify) {
   OggDemux* demux = new OggDemux(*this);
-  fDemuxesTable->Add((char const*)demux, demux);
+
+  DemuxRecord* demuxRecord = new DemuxRecord();
+  demuxRecord->demux = demux;
+  demuxRecord->onDeletionFunc = onDeletionFunc;
+  demuxRecord->objectToNotify = objectToNotify;
+
+  fDemuxesTable->Add((char const*)demux, demuxRecord);
 
   return demux;
 }
 
+void OggFile::removeDemux(OggDemux* demux) {
+  DemuxRecord* demuxRecord = (DemuxRecord*)(fDemuxesTable->Lookup((char const*)demux));
+  if (demuxRecord != NULL) {
+    fDemuxesTable->Remove((char const*)demux);
+
+    if (demuxRecord->onDeletionFunc != NULL) {
+      (*demuxRecord->onDeletionFunc)(demuxRecord->objectToNotify, demux);
+    }
+    delete demuxRecord;
+  }
+}
+
 unsigned OggFile::numTracks() const {
   return fTrackTable->numTracks();
 }
@@ -143,9 +168,10 @@ OggFile::~OggFile() {
   delete fParserForInitialization;
 
   // Delete any outstanding "OggDemux"s, and the table for them:
-  OggDemux* demux;
-  while ((demux = (OggDemux*)fDemuxesTable->RemoveNext()) != NULL) {
-    delete demux;
+  DemuxRecord* demuxRecord;
+  while ((demuxRecord = (DemuxRecord*)fDemuxesTable->RemoveNext()) != NULL) {
+    delete demuxRecord->demux;
+    delete demuxRecord;
   }
   delete fDemuxesTable;
   delete fTrackTable;
@@ -169,10 +195,6 @@ void OggFile::addTrack(OggTrack* newTrack) {
   fTrackTable->add(newTrack);
 }
 
-void OggFile::removeDemux(OggDemux* demux) {
-  fDemuxesTable->Remove((char const*)demux);
-}
-
 
 ////////// OggTrackTable implementation /////////
 
@@ -290,7 +312,7 @@ void OggDemux::removeTrack(u_int32_t trackNumber) {
   fDemuxedTracksTable->Remove((char const*)trackNumber);
   if (fDemuxedTracksTable->numEntries() == 0) {
     // We no longer have any demuxed tracks, so delete ourselves now:
-    delete this;
+    Medium::close(this);
   }
 }
 
